@@ -1,11 +1,10 @@
 from .resources import (
     AuthorResource, BookPrefixResource, ArticleResource, SomeOtherResource,
-    CustomResource, BSONResource, CSVResource)
+    CustomResource, CSVResource)
 from adrest.api import Api
 from adrest.utils.auth import AnonimousAuthenticator, AccessKeyAuthenticator, \
     UserAuthenticator
-from adrest.utils.emitter import XMLTemplateEmitter, JSONEmitter, BSONEmitter
-from adrest.utils.parser import BSONParser
+from adrest.utils.emitter import XMLTemplateEmitter, JSONEmitter
 from adrest.utils.throttle import CacheThrottle
 
 
@@ -23,7 +22,6 @@ API.register(BookPrefixResource)
 API.register(CustomResource)
 API.register(ArticleResource, authenticators=AccessKeyAuthenticator)
 API.register(SomeOtherResource, url_name='test', url_regex='test/mem/$')
-API.register(BSONResource, parsers=(BSONParser,), emitters=(BSONEmitter,))
 API.register(CSVResource)
 
 # lint_ignore=C
