@@ -1,4 +1,5 @@
-""" Prepare a Django project for tests. """
+""" Create Django project for testing. """
+
 from django.conf import settings
 
 # Configure Django
@@ -27,13 +28,13 @@ settings.configure(
     ),
 
     TEMPLATE_DEBUG=True,
-    TEMPLATE_CONTEXT_PROCESSORS = (
+    TEMPLATE_CONTEXT_PROCESSORS=(
         'django.core.context_processors.static',
         'django.core.context_processors.request',
         'django.contrib.auth.context_processors.auth',
     ),
 
-    EMAIL_BACKEND = 'django.core.mail.backends.locmem.EmailBackend',
+    EMAIL_BACKEND='django.core.mail.backends.locmem.EmailBackend',
 
     ADREST_ACCESS_LOG=True,
     ADREST_ALLOW_OPTIONS=True,
@@ -41,12 +42,21 @@ settings.configure(
     ADREST_AUTO_CREATE_ACCESSKEY=True,
 )
 
+# Django 1.7
+from django import VERSION
+
+if VERSION >= (1, 7):
+    from django.apps import apps
+
+    apps.populate(settings.INSTALLED_APPS)
+
+
 # Setup tests
 from django.core.management import call_command
 call_command('syncdb', interactive=False)
 
-from .core.tests   import *
-from .main.tests   import *
-from .rpc.tests    import *
+from .core.tests import * # noqa
+from .main.tests import * # noqa
+from .rpc.tests import * # noqa
 
 # lint_ignore=W0614,W0401,E272
